OC.L10N.register(
    "files",
    {
    "Unknown error" : "Error desconocido",
    "Download" : "Descargar",
    "Rename" : "Renombrar",
    "Files" : "Archivos",
    "Details" : "detalles",
    "New folder" : "Nuevo directorio",
    "Upload" : "Subir",
    "A new file or folder has been <strong>created</strong>" : "Un nuevo archivo o carpeta ha sido <strong>creado</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un archivo o carpeta ha sido <strong>cambiado</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un archivo o carpeta ha sido <strong>eliminado</strong>",
    "You created %1$s" : "Ha creado %1$s",
    "%2$s created %1$s" : "%2$s creó %1$s",
    "You changed %1$s" : "Cambió %1$s",
    "%2$s changed %1$s" : "%2$s cambió %1$s",
    "You deleted %1$s" : "Ha borrado %1$s",
    "%2$s deleted %1$s" : "%2$s borró %1$s",
    "Settings" : "Configuración"
},
"nplurals=2; plural=(n != 1);");
